@@ -24,7 +24,7 @@ from rally.benchmark import utils as bench_utils
 from rally import exceptions
 
 
-nova_benchmark_opts = []
+NOVA_BENCHMARK_OPTS = []
 option_names_and_defaults = [
     # action, prepoll delay, timeout, poll interval
     ("start", 0, 300, 1),
@@ -45,7 +45,7 @@ option_names_and_defaults = [
 ]
 
 for action, prepoll, timeout, poll in option_names_and_defaults:
-    nova_benchmark_opts.extend([
+    NOVA_BENCHMARK_OPTS.extend([
         cfg.FloatOpt(
             "nova_server_%s_prepoll_delay" % action,
             default=float(prepoll),
@@ -67,7 +67,7 @@ CONF = cfg.CONF
 benchmark_group = cfg.OptGroup(name="benchmark",
                                title="benchmark options")
 CONF.register_group(benchmark_group)
-CONF.register_opts(nova_benchmark_opts, group=benchmark_group)
+CONF.register_opts(NOVA_BENCHMARK_OPTS, group=benchmark_group)
 
 
 class NovaScenario(base.Scenario):
@@ -79,8 +79,8 @@ class NovaScenario(base.Scenario):
         return self.clients("nova").servers.list(detailed)
 
     @base.atomic_action_timer("nova.boot_server")
-    def _boot_server(self, server_name, image_id, flavor_id,
-                     auto_assign_nic=False, **kwargs):
+    def _boot_server(self, image_id, flavor_id,
+                     auto_assign_nic=False, name=None, **kwargs):
         """Boot a server.
 
         Returns when the server is actually booted and in "ACTIVE" state.
@@ -88,23 +88,24 @@ class NovaScenario(base.Scenario):
         If multiple networks are present, the first network found that
         isn't associated with a floating IP pool is used.
 
-        :param server_name: str, server name
         :param image_id: int, image ID for server creation
         :param flavor_id: int, flavor ID for server creation
         :param auto_assign_nic: bool, whether or not to auto assign NICs
+        :param name: str, server name
         :param kwargs: other optional parameters to initialize the server
         :returns: nova Server instance
         """
-        allow_ssh_secgroup = self.context.get("allow_ssh")
-        if allow_ssh_secgroup:
+        server_name = name or self._generate_random_name()
+        secgroup = self.context.get("user", {}).get("secgroup")
+        if secgroup:
             if "security_groups" not in kwargs:
-                kwargs["security_groups"] = [allow_ssh_secgroup]
-            elif allow_ssh_secgroup not in kwargs["security_groups"]:
-                kwargs["security_groups"].append(allow_ssh_secgroup)
+                kwargs["security_groups"] = [secgroup["name"]]
+            elif secgroup["name"] not in kwargs["security_groups"]:
+                kwargs["security_groups"].append(secgroup["name"])
 
         if auto_assign_nic and not kwargs.get("nics", False):
-            nets = [net["id"]
-                    for net in self.context["tenant"].get("networks", [])]
+            nets = [net["id"] for net in
+                    self.context.get("tenant", {}).get("networks", [])]
             if nets:
                 # NOTE(amaretskiy): Balance servers among networks:
                 #     divmod(iteration % tenants_num, nets_num)[1]
@@ -321,6 +322,29 @@ class NovaScenario(base.Scenario):
         )
         return image
 
+    @base.atomic_action_timer("nova.create_keypair")
+    def _create_keypair(self, **kwargs):
+        """Create a keypair
+
+        :returns: Created keypair name
+        """
+        keypair_name = self._generate_random_name(prefix="rally_keypair_")
+        keypair = self.clients("nova").keypairs.create(keypair_name, **kwargs)
+        return keypair.name
+
+    @base.atomic_action_timer("nova.list_keypairs")
+    def _list_keypairs(self):
+        """Return user keypairs list."""
+        return self.clients("nova").keypairs.list()
+
+    @base.atomic_action_timer("nova.delete_keypair")
+    def _delete_keypair(self, keypair_name):
+        """Delete keypair
+
+        :param keypair_name: The keypair name to delete.
+        """
+        self.clients("nova").keypairs.delete(keypair_name)
+
     @base.atomic_action_timer("nova.boot_servers")
     def _boot_servers(self, name_prefix, image_id, flavor_id,
                       requests, instances_amount=1, **kwargs):
@@ -360,38 +384,6 @@ class NovaScenario(base.Scenario):
         ) for server in servers]
         return servers
 
-    @base.atomic_action_timer("nova.list_floating_ip_pools")
-    def _list_floating_ip_pools(self):
-        """Return user floating ip pools list."""
-        return self.clients("nova").floating_ip_pools.list()
-
-    @base.atomic_action_timer("nova.list_floating_ips")
-    def _list_floating_ips(self):
-        """Return user floating ips list."""
-        return self.clients("nova").floating_ips.list()
-
-    @base.atomic_action_timer("nova.create_floating_ip")
-    def _create_floating_ip(self, pool):
-        """Create (allocate) a floating ip from the given pool
-
-        :param pool: Name of the floating ip pool or external network
-
-        :returns: The created floating ip
-        """
-        return self.clients("nova").floating_ips.create(pool)
-
-    @base.atomic_action_timer("nova.delete_floating_ip")
-    def _delete_floating_ip(self, floating_ip):
-        """Delete (deallocate) a  floating ip for a tenant
-
-        :param floating_ip: The floating ip address to delete.
-        """
-        self.clients("nova").floating_ips.delete(floating_ip)
-        bench_utils.wait_for_delete(
-            floating_ip,
-            update_resource=bench_utils.get_from_manager()
-        )
-
     @base.atomic_action_timer("nova.associate_floating_ip")
     def _associate_floating_ip(self, server, address, fixed_address=None):
         """Add floating IP to an instance
@@ -435,7 +427,7 @@ class NovaScenario(base.Scenario):
                 for addr in addr_list:
                         if ip_to_check == addr["addr"]:
                             return must_exist
-                return not must_exist
+            return not must_exist
         return _check_addr
 
     @base.atomic_action_timer("nova.list_networks")
@@ -566,7 +558,7 @@ class NovaScenario(base.Scenario):
             raise exceptions.InvalidHostException(
                 "No valid host found to migrate")
 
-    @base.atomic_action_timer('nova.migrate')
+    @base.atomic_action_timer("nova.migrate")
     def _migrate(self, server, skip_host_check=False):
         """Run migration of the given server.
 
