@@ -30,8 +30,8 @@ from rally import api
 from rally.benchmark.processing import plot
 from rally.benchmark.processing import utils
 from rally.cmd import cliutils
-from rally.cmd.commands import use
 from rally.cmd import envutils
+from rally.common import fileutils
 from rally.common.i18n import _
 from rally.common import log as logging
 from rally.common import utils as rutils
@@ -39,7 +39,6 @@ from rally import consts
 from rally import db
 from rally import exceptions
 from rally import objects
-from rally.openstack.common import cliutils as common_cliutils
 
 
 class FailedToLoadTask(exceptions.RallyException):
@@ -105,7 +104,7 @@ class TaskCommands(object):
         with open(task_file) as f:
             try:
                 input_task = f.read()
-                rendered_task = api.task_template_render(input_task, **kw)
+                rendered_task = api.Task.render_template(input_task, **kw)
             except Exception as e:
                 print(_("Failed to render task template:\n%(task)s\n%(err)s\n")
                       % {"task": input_task, "err": e},
@@ -157,7 +156,7 @@ class TaskCommands(object):
             return(1)
 
         try:
-            api.task_validate(deployment, input_task)
+            api.Task.validate(deployment, input_task)
             print("Task config is valid :)")
         except exceptions.InvalidTaskException as e:
             print("Task config is invalid: \n")
@@ -180,9 +179,13 @@ class TaskCommands(object):
     @cliutils.args("--tag", help="Tag for this task")
     @cliutils.args("--no-use", action="store_false", dest="do_use",
                    help="Don't set new task as default for future operations")
+    @cliutils.args("--abort-on-sla-failure", action="store_true",
+                   dest="abort_on_sla_failure",
+                   help="Abort the execution of a benchmark scenario when"
+                        "any SLA check for it fails")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def start(self, task, deployment=None, task_args=None, task_args_file=None,
-              tag=None, do_use=False):
+              tag=None, do_use=False, abort_on_sla_failure=False):
         """Start benchmark task.
 
         :param task: a file with yaml/json task
@@ -193,6 +196,11 @@ class TaskCommands(object):
                                is jinja2 template.
         :param deployment: UUID or name of a deployment
         :param tag: optional tag for this task
+        :param do_use: if True, the new task will be stored as the default one
+                       for future operations
+        :param abort_on_sla_failure: if True, the execution of a benchmark
+                                     scenario will stop when any SLA check
+                                     for it fails
         """
         try:
             input_task = self._load_task(task, task_args, task_args_file)
@@ -200,17 +208,18 @@ class TaskCommands(object):
             return(1)
 
         try:
-            task = api.create_task(deployment, tag)
+            task = api.Task.create(deployment, tag)
             print(cliutils.make_header(
                   _("Task %(tag)s %(uuid)s: started")
                   % {"uuid": task["uuid"], "tag": task["tag"]}))
             print("Benchmarking... This can take a while...\n")
             print("To track task status use:\n")
             print("\trally task status\n\tor\n\trally task detailed\n")
-            api.start_task(deployment, input_task, task=task)
+            api.Task.start(deployment, input_task, task=task,
+                           abort_on_sla_failure=abort_on_sla_failure)
             self.detailed(task_id=task["uuid"])
             if do_use:
-                use.UseCommands().task(task["uuid"])
+                self.use(task["uuid"])
         except exceptions.InvalidConfigException:
             return(1)
 
@@ -222,7 +231,7 @@ class TaskCommands(object):
         :param task_id: Task uuid
         """
 
-        api.abort_task(task_id)
+        api.Task.abort(task_id)
 
     @cliutils.args("--uuid", type=str, dest="task_id", help="UUID of task")
     @envutils.with_default_task_id
@@ -273,19 +282,13 @@ class TaskCommands(object):
                                    for col in float_cols]))
             for (c, r) in enumerate(raw_data, 1):
                 dlist = [c]
+                dlist.append(r["duration"])
                 if r["atomic_actions"]:
-                    dlist.append(r["duration"])
                     for action in atomic_actions:
                         dlist.append(r["atomic_actions"].get(action) or 0)
-                    table_rows.append(rutils.Struct(**dict(zip(headers,
-                                                               dlist))))
-                else:
-                    data = dlist + [None for i in range(1, len(headers))]
-                    table_rows.append(rutils.Struct(**dict(zip(headers,
-                                                               data))))
-            common_cliutils.print_list(table_rows,
-                                       fields=headers,
-                                       formatters=formatters)
+            cliutils.print_list(table_rows,
+                                fields=headers,
+                                formatters=formatters)
             print()
 
         task = db.task_get_detailed(task_id)
@@ -350,8 +353,8 @@ class TaskCommands(object):
                             "0.0%", len(raw)]
                 table_rows.append(rutils.Struct(**dict(zip(table_cols, data))))
 
-            common_cliutils.print_list(table_rows, fields=table_cols,
-                                       formatters=formatters)
+            cliutils.print_list(table_rows, fields=table_cols,
+                                formatters=formatters)
 
             if iterations_data:
                 _print_iterations_data(raw)
@@ -391,9 +394,9 @@ class TaskCommands(object):
                         row = [str(key)] + ["n/a"] * 5
                     table_rows.append(rutils.Struct(**dict(zip(headers, row))))
                 print("\nScenario Specific Results\n")
-                common_cliutils.print_list(table_rows,
-                                           fields=headers,
-                                           formatters=formatters)
+                cliutils.print_list(table_rows,
+                                    fields=headers,
+                                    formatters=formatters)
 
                 for result in raw:
                     errors = result["scenario_output"].get("errors")
@@ -410,6 +413,7 @@ class TaskCommands(object):
 
     @cliutils.args("--uuid", type=str, dest="task_id", help="uuid of task")
     @envutils.with_default_task_id
+    @cliutils.suppress_warnings
     def results(self, task_id=None):
         """Display raw task results.
 
@@ -418,11 +422,11 @@ class TaskCommands(object):
         :param task_id: Task uuid
         """
 
-        results = map(lambda x: {"key": x["key"], "result": x["data"]["raw"],
-                                 "sla": x["data"]["sla"],
-                                 "load_duration": x["data"]["load_duration"],
-                                 "full_duration": x["data"]["full_duration"]},
-                      objects.Task.get(task_id).get_results())
+        results = [{"key": x["key"], "result": x["data"]["raw"],
+                    "sla": x["data"]["sla"],
+                    "load_duration": x["data"]["load_duration"],
+                    "full_duration": x["data"]["full_duration"]}
+                   for x in objects.Task.get(task_id).get_results()]
 
         if results:
             print(json.dumps(results, sort_keys=True, indent=4))
@@ -468,13 +472,13 @@ class TaskCommands(object):
         if not all_deployments:
             filters.setdefault("deployment", deployment)
 
-        task_list = map(lambda x: x.to_dict(), objects.Task.list(**filters))
+        task_list = [task.to_dict() for task in objects.Task.list(**filters)]
 
         for x in task_list:
             x["duration"] = x["updated_at"] - x["created_at"]
 
         if task_list:
-            common_cliutils.print_list(
+            cliutils.print_list(
                 task_list,
                 headers, sortby_index=headers.index("created_at"))
         else:
@@ -488,14 +492,15 @@ class TaskCommands(object):
 
     @cliutils.args("--tasks", dest="tasks", nargs="+",
                    help="uuids of tasks or json files with task results")
-    @cliutils.args('--out', type=str, dest='out', required=True,
-                   help='Path to output file.')
-    @cliutils.args('--open', dest='open_it', action='store_true',
-                   help='Open it in browser.')
+    @cliutils.args("--out", type=str, dest="out", required=True,
+                   help="Path to output file.")
+    @cliutils.args("--open", dest="open_it", action="store_true",
+                   help="Open it in browser.")
     @cliutils.deprecated_args(
         "--uuid", dest="tasks", nargs="+",
         help="uuids of tasks or json files with task results")
     @envutils.default_from_global("tasks", envutils.ENV_TASK, "--uuid")
+    @cliutils.suppress_warnings
     def report(self, tasks=None, out=None, open_it=False):
         """Generate HTML report file for specified task.
 
@@ -570,11 +575,20 @@ class TaskCommands(object):
         :param force: Force delete or not
         """
 
+        def _delete_single_task(tid, force):
+            try:
+                api.Task.delete(tid, force=force)
+                print("Successfully deleted task `%s`" % tid)
+            except exceptions.TaskInvalidStatus as e:
+                print(e)
+                print("Use '--force' option to delete the task with vague "
+                      "state.")
+
         if isinstance(task_id, list):
             for tid in task_id:
-                api.delete_task(tid, force=force)
+                _delete_single_task(tid, force)
         else:
-            api.delete_task(task_id, force=force)
+            _delete_single_task(task_id, force)
 
     @cliutils.args("--uuid", type=str, dest="task_id", help="uuid of task")
     @cliutils.args("--json", dest="tojson",
@@ -594,7 +608,8 @@ class TaskCommands(object):
         STATUS_FAIL = "FAIL"
         for result in results:
             key = result["key"]
-            for sla in result["data"]["sla"]:
+            for sla in sorted(result["data"]["sla"],
+                              key=lambda x: x["criterion"]):
                 success = sla.pop("success")
                 sla["status"] = success and STATUS_PASS or STATUS_FAIL
                 sla["benchmark"] = key["name"]
@@ -602,8 +617,19 @@ class TaskCommands(object):
                 failed_criteria += int(not success)
                 data.append(sla if tojson else rutils.Struct(**sla))
         if tojson:
-            print(json.dumps(data))
+            print(json.dumps(data, sort_keys=False))
         else:
-            common_cliutils.print_list(data, ("benchmark", "pos", "criterion",
-                                              "status", "detail"))
+            cliutils.print_list(data, ("benchmark", "pos", "criterion",
+                                       "status", "detail"))
         return failed_criteria
+
+    @cliutils.args("--task", type=str, dest="task", required=False,
+                   help="UUID of the task")
+    def use(self, task):
+        """Set active task. Alias for "rally use task".
+
+        :param task: Task uuid.
+        """
+        print("Using task: %s" % task)
+        db.task_get(task)
+        fileutils.update_globals_file("RALLY_TASK", task)
