@@ -30,7 +30,7 @@ NOVA_SERVERS = NOVA_SERVERS_MODULE + ".NovaServers"
 class NovaServersTestCase(test.TestCase):
 
     def test_boot_rescue_unrescue(self):
-        actions = [{'rescue_unrescue': 5}]
+        actions = [{"rescue_unrescue": 5}]
         fake_server = mock.MagicMock()
         scenario = servers.NovaServers()
         scenario._boot_server = mock.MagicMock(return_value=fake_server)
@@ -40,7 +40,7 @@ class NovaServersTestCase(test.TestCase):
         scenario._delete_server = mock.MagicMock()
 
         scenario.boot_and_bounce_server("img", 1, actions=actions)
-        scenario._boot_server.assert_called_once_with("name", "img", 1)
+        scenario._boot_server.assert_called_once_with("img", 1)
         server_calls = []
         for i in range(5):
             server_calls.append(mock.call(fake_server))
@@ -54,7 +54,7 @@ class NovaServersTestCase(test.TestCase):
                                                         force=False)
 
     def test_boot_stop_start(self):
-        actions = [{'stop_start': 5}]
+        actions = [{"stop_start": 5}]
         fake_server = mock.MagicMock()
         scenario = servers.NovaServers()
         scenario._boot_server = mock.MagicMock(return_value=fake_server)
@@ -65,7 +65,7 @@ class NovaServersTestCase(test.TestCase):
 
         scenario.boot_and_bounce_server("img", 1, actions=actions)
 
-        scenario._boot_server.assert_called_once_with("name", "img", 1)
+        scenario._boot_server.assert_called_once_with("img", 1)
         server_calls = []
         for i in range(5):
             server_calls.append(mock.call(fake_server))
@@ -79,7 +79,7 @@ class NovaServersTestCase(test.TestCase):
                                                         force=False)
 
     def test_multiple_bounce_actions(self):
-        actions = [{'hard_reboot': 5}, {'stop_start': 8}]
+        actions = [{"hard_reboot": 5}, {"stop_start": 8}]
         fake_server = mock.MagicMock()
         scenario = servers.NovaServers()
 
@@ -87,10 +87,10 @@ class NovaServersTestCase(test.TestCase):
         scenario._delete_server = mock.MagicMock()
         scenario._reboot_server = mock.MagicMock()
         scenario._stop_and_start_server = mock.MagicMock()
-        scenario._generate_random_name = mock.MagicMock(return_value='name')
+        scenario._generate_random_name = mock.MagicMock(return_value="name")
 
         scenario.boot_and_bounce_server("img", 1, actions=actions)
-        scenario._boot_server.assert_called_once_with("name", "img", 1)
+        scenario._boot_server.assert_called_once_with("img", 1)
         server_calls = []
         for i in range(5):
             server_calls.append(mock.call(fake_server))
@@ -131,7 +131,7 @@ class NovaServersTestCase(test.TestCase):
                           1, 1, actions=actions)
 
     def _verify_reboot(self, soft=True):
-        actions = [{'soft_reboot' if soft else 'hard_reboot': 5}]
+        actions = [{"soft_reboot" if soft else "hard_reboot": 5}]
         fake_server = mock.MagicMock()
         scenario = servers.NovaServers()
 
@@ -139,11 +139,11 @@ class NovaServersTestCase(test.TestCase):
         scenario._soft_reboot_server = mock.MagicMock()
         scenario._boot_server = mock.MagicMock(return_value=fake_server)
         scenario._delete_server = mock.MagicMock()
-        scenario._generate_random_name = mock.MagicMock(return_value='name')
+        scenario._generate_random_name = mock.MagicMock(return_value="name")
 
         scenario.boot_and_bounce_server("img", 1, actions=actions)
 
-        scenario._boot_server.assert_called_once_with("name", "img", 1)
+        scenario._boot_server.assert_called_once_with("img", 1)
         server_calls = []
         for i in range(5):
             server_calls.append(mock.call(fake_server))
@@ -175,7 +175,7 @@ class NovaServersTestCase(test.TestCase):
 
         scenario.boot_and_delete_server("img", 0, 10, 20, fakearg="fakearg")
 
-        scenario._boot_server.assert_called_once_with("name", "img", 0,
+        scenario._boot_server.assert_called_once_with("img", 0,
                                                       fakearg="fakearg")
         scenario.sleep_between.assert_called_once_with(10, 20)
         scenario._delete_server.assert_called_once_with(fake_server,
@@ -189,7 +189,7 @@ class NovaServersTestCase(test.TestCase):
 
         scenario.boot_and_list_server("img", 0, fakearg="fakearg")
 
-        scenario._boot_server.assert_called_once_with("name", "img", 0,
+        scenario._boot_server.assert_called_once_with("img", 0,
                                                       fakearg="fakearg")
         scenario._list_servers.assert_called_once_with(True)
 
@@ -216,8 +216,8 @@ class NovaServersTestCase(test.TestCase):
 
         scenario._create_volume.assert_called_once_with(5, imageRef="img")
         scenario._boot_server.assert_called_once_with(
-            "name", "img", 0,
-            block_device_mapping={'vda': 'volume_id:::1'},
+            "img", 0,
+            block_device_mapping={"vda": "volume_id:::1"},
             fakearg="f")
         scenario.sleep_between.assert_called_once_with(10, 20)
         scenario._delete_server.assert_called_once_with(fake_server,
@@ -238,15 +238,15 @@ class NovaServersTestCase(test.TestCase):
         scenario._boot_server = mock.MagicMock(return_value=fake_server)
         scenario._generate_random_name = mock.MagicMock(return_value="name")
 
-        kwargs = {'fakearg': 'f'}
-        expected_kwargs = {'fakearg': 'f'}
+        kwargs = {"fakearg": "f"}
+        expected_kwargs = {"fakearg": "f"}
 
         assert_nic = nic or assert_nic
         if nic:
-            kwargs['nics'] = nic
+            kwargs["nics"] = nic
         if assert_nic:
-            nova.networks.create('net-1')
-            expected_kwargs['nics'] = nic or [{'net-id': 'net-2'}]
+            nova.networks.create("net-1")
+            expected_kwargs["nics"] = nic or [{"net-id": "net-2"}]
 
         print(kwargs)
         print(expected_kwargs)
@@ -259,8 +259,8 @@ class NovaServersTestCase(test.TestCase):
             nic=nic, assert_nic=assert_nic)
 
         scenario.boot_server("img", 0, **kwargs)
-        scenario._boot_server.assert_called_once_with("name", "img", 0, False,
-                                                      **expected_kwargs)
+        scenario._boot_server.assert_called_once_with(
+            "img", 0, auto_assign_nic=False, **expected_kwargs)
 
     @mock.patch("rally.benchmark.scenarios.nova.servers.NovaServers.clients")
     @mock.patch("rally.benchmark.runners.base.osclients")
@@ -272,7 +272,7 @@ class NovaServersTestCase(test.TestCase):
     @mock.patch("rally.benchmark.runners.base.osclients")
     def test_boot_server_with_nic(self, mock_osclients):
         self._verify_boot_server(mock_osclients=mock_osclients,
-                                 nic=[{'net-id': 'net-1'}], assert_nic=True)
+                                 nic=[{"net-id": "net-1"}], assert_nic=True)
 
     def test_snapshot_server(self):
         fake_server = object()
@@ -289,8 +289,8 @@ class NovaServersTestCase(test.TestCase):
         scenario.snapshot_server("i", 0, fakearg=2)
 
         scenario._boot_server.assert_has_calls([
-            mock.call("name", "i", 0, fakearg=2),
-            mock.call("name", "image_id", 0, fakearg=2)])
+            mock.call("i", 0, fakearg=2),
+            mock.call("image_id", 0, fakearg=2)])
         scenario._create_image.assert_called_once_with(fake_server)
         scenario._delete_server.assert_has_calls([
             mock.call(fake_server, force=False),
@@ -312,7 +312,7 @@ class NovaServersTestCase(test.TestCase):
         scenario._resize = mock.MagicMock()
         scenario._delete_server = mock.MagicMock()
 
-        kwargs = {'confirm': confirm}
+        kwargs = {"confirm": confirm}
         scenario.resize_server(fake_image, flavor, to_flavor, **kwargs)
 
         scenario._resize.assert_called_once_with(fake_server, to_flavor)
@@ -341,7 +341,7 @@ class NovaServersTestCase(test.TestCase):
 
         scenario.boot_and_live_migrate_server("img", 0, fakearg="fakearg")
 
-        scenario._boot_server.assert_called_once_with("name", "img", 0,
+        scenario._boot_server.assert_called_once_with("img", 0,
                                                       fakearg="fakearg")
 
         scenario._find_host_to_migrate.assert_called_once_with(fake_server)
@@ -351,6 +351,72 @@ class NovaServersTestCase(test.TestCase):
                                                        False, False)
         scenario._delete_server.assert_called_once_with(fake_server)
 
+    def test_boot_server_from_volume_and_live_migrate(self):
+        fake_server = mock.MagicMock()
+
+        scenario = servers.NovaServers()
+        scenario._generate_random_name = mock.MagicMock(return_value="name")
+        scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario._find_host_to_migrate = mock.MagicMock(
+                                         return_value="host_name")
+        scenario._live_migrate = mock.MagicMock()
+        scenario._delete_server = mock.MagicMock()
+
+        fake_volume = fakes.FakeVolumeManager().create()
+        fake_volume.id = "volume_id"
+        scenario._create_volume = mock.MagicMock(return_value=fake_volume)
+
+        scenario.boot_server_from_volume_and_live_migrate("img", 0, 5,
+                                                          fakearg="f")
+
+        scenario._create_volume.assert_called_once_with(5, imageRef="img")
+
+        scenario._boot_server.assert_called_once_with(
+            "img", 0,
+            block_device_mapping={"vda": "volume_id:::1"},
+            fakearg="f")
+
+        scenario._find_host_to_migrate.assert_called_once_with(fake_server)
+
+        scenario._live_migrate.assert_called_once_with(fake_server,
+                                                       "host_name",
+                                                       False, False)
+        scenario._delete_server.assert_called_once_with(fake_server,
+                                                        force=False)
+
+    def test_boot_server_attach_created_volume_and_live_migrate(self):
+        fake_volume = mock.MagicMock()
+        fake_server = mock.MagicMock()
+
+        scenario = servers.NovaServers()
+
+        scenario._attach_volume = mock.MagicMock()
+        scenario._detach_volume = mock.MagicMock()
+
+        scenario._find_host_to_migrate = mock.MagicMock(
+                                         return_value="host_name")
+        scenario._live_migrate = mock.MagicMock()
+
+        scenario._boot_server = mock.MagicMock(return_value=fake_server)
+        scenario._delete_server = mock.MagicMock()
+        scenario._create_volume = mock.MagicMock(return_value=fake_volume)
+        scenario._delete_volume = mock.MagicMock()
+
+        scenario.boot_server_attach_created_volume_and_live_migrate(
+            "img",
+            0,
+            5)
+        scenario._attach_volume.assert_called_once_with(fake_server,
+                                                        fake_volume)
+        scenario._detach_volume.assert_called_once_with(fake_server,
+                                                        fake_volume)
+        scenario._live_migrate.assert_called_once_with(fake_server,
+                                                       "host_name",
+                                                       False, False)
+
+        scenario._delete_volume.assert_called_once_with(fake_volume)
+        scenario._delete_server.assert_called_once_with(fake_server)
+
     def _test_boot_and_migrate_server(self, confirm=False):
         fake_server = mock.MagicMock()
 
@@ -367,7 +433,7 @@ class NovaServersTestCase(test.TestCase):
         scenario.boot_and_migrate_server("img", 0,
                                          fakearg="fakearg", **kwargs)
 
-        scenario._boot_server.assert_called_once_with("name", "img", 0,
+        scenario._boot_server.assert_called_once_with("img", 0,
                                                       fakearg="fakearg",
                                                       confirm=confirm)
 
