@@ -15,6 +15,7 @@
 
 import copy
 import datetime as date
+import os.path
 
 import mock
 
@@ -100,8 +101,8 @@ class TaskCommandsTestCase(test.TestCase):
     @mock.patch("rally.cmd.commands.task.TaskCommands.detailed")
     @mock.patch("rally.cmd.commands.task.TaskCommands._load_task",
                 return_value={"some": "json"})
-    @mock.patch("rally.api.create_task")
-    @mock.patch("rally.cmd.commands.task.api.start_task")
+    @mock.patch("rally.api.Task.create")
+    @mock.patch("rally.cmd.commands.task.api.Task.start")
     def test_start(self, mock_api, mock_create_task, mock_load,
                    mock_task_detailed):
         mock_create_task.return_value = (
@@ -112,7 +113,8 @@ class TaskCommandsTestCase(test.TestCase):
         task_path = "path_to_config.json"
         self.task.start(task_path, deployment_id)
         mock_api.assert_called_once_with(deployment_id, {"some": "json"},
-                                         task=mock_create_task.return_value)
+                                         task=mock_create_task.return_value,
+                                         abort_on_sla_failure=False)
         mock_load.assert_called_once_with(task_path, None, None)
 
     @mock.patch("rally.cmd.commands.task.TaskCommands._load_task",
@@ -134,22 +136,22 @@ class TaskCommandsTestCase(test.TestCase):
     @mock.patch("rally.cmd.commands.task.TaskCommands._load_task")
     @mock.patch("rally.cmd.commands.task.api")
     def test_start_invalid_task(self, mock_api, mock_load):
-        mock_api.start_task.side_effect = exceptions.InvalidConfigException
+        mock_api.Task.start.side_effect = exceptions.InvalidConfigException
 
         result = self.task.start("task_path", "deployment", tag="tag")
         self.assertEqual(1, result)
 
-        mock_api.create_task.assert_called_once_with("deployment", "tag")
-        mock_api.start_task.assert_called_once_with(
+        mock_api.Task.create.assert_called_once_with("deployment", "tag")
+        mock_api.Task.start.assert_called_once_with(
             "deployment", mock_load.return_value,
-            task=mock_api.create_task.return_value)
+            task=mock_api.Task.create.return_value, abort_on_sla_failure=False)
 
     @mock.patch("rally.cmd.commands.task.api")
     def test_abort(self, mock_api):
         test_uuid = "17860c43-2274-498d-8669-448eff7b073f"
-        mock_api.abort_task = mock.MagicMock()
+        mock_api.Task.abort = mock.MagicMock()
         self.task.abort(test_uuid)
-        task.api.abort_task.assert_called_once_with(test_uuid)
+        task.api.Task.abort.assert_called_once_with(test_uuid)
 
     @mock.patch("rally.cmd.commands.task.envutils.get_global")
     def test_abort_no_task_id(self, mock_default):
@@ -294,7 +296,11 @@ class TaskCommandsTestCase(test.TestCase):
         mock_get.return_value = mock.Mock(get_results=mock_results)
 
         self.task.results(task_id)
-        mock_json.assert_called_once_with(result, sort_keys=True, indent=4)
+        self.assertEqual(1, mock_json.call_count)
+        self.assertEqual(1, len(mock_json.call_args[0]))
+        self.assertSequenceEqual(result, mock_json.call_args[0][0])
+        self.assertEqual({"sort_keys": True, "indent": 4},
+                         mock_json.call_args[1])
         mock_get.assert_called_once_with(task_id)
 
     @mock.patch("rally.cmd.commands.task.objects.Task.get")
@@ -330,12 +336,12 @@ class TaskCommandsTestCase(test.TestCase):
                       "load_duration": 2.1,
                       "full_duration": 2.2}}]
 
-        results = map(lambda x: {"key": x["key"],
-                                 "result": x["data"]["raw"],
-                                 "sla": x["data"]["sla"],
-                                 "load_duration": x["data"]["load_duration"],
-                                 "full_duration": x["data"]["full_duration"]},
-                      data)
+        results = [{"key": x["key"],
+                    "result": x["data"]["raw"],
+                    "sla": x["data"]["sla"],
+                    "load_duration": x["data"]["load_duration"],
+                    "full_duration": x["data"]["full_duration"]}
+                   for x in data]
         mock_results = mock.Mock(return_value=data)
         mock_get.return_value = mock.Mock(get_results=mock_results)
         mock_plot.plot.return_value = "html_report"
@@ -425,12 +431,12 @@ class TaskCommandsTestCase(test.TestCase):
                       "load_duration": 2.1,
                       "full_duration": 2.2}}]
 
-        results = map(lambda x: {"key": x["key"],
-                                 "result": x["data"]["raw"],
-                                 "sla": x["data"]["sla"],
-                                 "load_duration": x["data"]["load_duration"],
-                                 "full_duration": x["data"]["full_duration"]},
-                      data)
+        results = [{"key": x["key"],
+                    "result": x["data"]["raw"],
+                    "sla": x["data"]["sla"],
+                    "load_duration": x["data"]["load_duration"],
+                    "full_duration": x["data"]["full_duration"]}
+                   for x in data]
 
         mock_plot.plot.return_value = "html_report"
         mock_open.side_effect = mock.mock_open(read_data=results)
@@ -474,7 +480,7 @@ class TaskCommandsTestCase(test.TestCase):
                                out="/tmp/tmp.hsml")
         self.assertEqual(ret, 1)
 
-    @mock.patch("rally.cmd.commands.task.common_cliutils.print_list")
+    @mock.patch("rally.cmd.commands.task.cliutils.print_list")
     @mock.patch("rally.cmd.commands.task.envutils.get_global",
                 return_value="123456789")
     @mock.patch("rally.cmd.commands.task.objects.Task.list",
@@ -493,9 +499,10 @@ class TaskCommandsTestCase(test.TestCase):
 
         headers = ["uuid", "deployment_name", "created_at", "duration",
                    "status", "tag"]
+
         mock_print_list.assert_called_once_with(
             mock_objects_list.return_value, headers,
-            sortby_index=headers.index('created_at'))
+            sortby_index=headers.index("created_at"))
 
     def test_list_wrong_status(self):
         self.assertEqual(1, self.task.list(deployment="fake",
@@ -518,9 +525,9 @@ class TaskCommandsTestCase(test.TestCase):
         task_uuid = "8dcb9c5e-d60b-4022-8975-b5987c7833f7"
         force = False
         with mock.patch("rally.cmd.commands.task.api") as mock_api:
-            mock_api.delete_task = mock.Mock()
+            mock_api.Task.delete = mock.Mock()
             self.task.delete(task_uuid, force=force)
-            mock_api.delete_task.assert_called_once_with(task_uuid,
+            mock_api.Task.delete.assert_called_once_with(task_uuid,
                                                          force=force)
 
     @mock.patch("rally.cmd.commands.task.api")
@@ -531,12 +538,12 @@ class TaskCommandsTestCase(test.TestCase):
                       "018af931-0e5a-40d5-9d6f-b13f4a3a09fc"]
         force = False
         self.task.delete(task_uuids, force=force)
-        self.assertTrue(mock_api.delete_task.call_count == len(task_uuids))
+        self.assertTrue(mock_api.Task.delete.call_count == len(task_uuids))
         expected_calls = [mock.call(task_uuid, force=force) for task_uuid
                           in task_uuids]
-        self.assertTrue(mock_api.delete_task.mock_calls == expected_calls)
+        self.assertTrue(mock_api.Task.delete.mock_calls == expected_calls)
 
-    @mock.patch("rally.cmd.commands.task.common_cliutils.print_list")
+    @mock.patch("rally.cmd.commands.task.cliutils.print_list")
     @mock.patch("rally.cmd.commands.task.objects.Task.get")
     def test_sla_check(self, mock_task_get, mock_print_list):
         data = [{"key": {"name": "fake_name",
@@ -564,7 +571,7 @@ class TaskCommandsTestCase(test.TestCase):
     @mock.patch("rally.cmd.commands.task.open",
                 mock.mock_open(read_data="{\"some\": \"json\"}"),
                 create=True)
-    @mock.patch("rally.api.task_validate")
+    @mock.patch("rally.api.Task.validate")
     def test_validate(self, mock_validate):
         self.task.validate("path_to_config.json", "fake_id")
         mock_validate.assert_called_once_with("fake_id", {"some": "json"})
@@ -581,7 +588,7 @@ class TaskCommandsTestCase(test.TestCase):
         mock_load.assert_called_once_with("path_to_task", args, args_file)
 
     @mock.patch("rally.cmd.commands.task.TaskCommands._load_task")
-    @mock.patch("rally.api.task_validate")
+    @mock.patch("rally.api.Task.validate")
     def test_validate_invalid(self, mock_task_validate, mock_load):
 
         mock_task_validate.side_effect = exceptions.InvalidTaskException
@@ -589,3 +596,18 @@ class TaskCommandsTestCase(test.TestCase):
         self.assertEqual(1, result)
         mock_task_validate.assert_called_once_with("deployment",
                                                    mock_load.return_value)
+
+    @mock.patch("rally.common.fileutils._rewrite_env_file")
+    @mock.patch("rally.cmd.commands.task.db.task_get", return_value=True)
+    def test_use(self, mock_task, mock_file):
+        task_id = "80422553-5774-44bd-98ac-38bd8c7a0feb"
+        self.task.use(task_id)
+        mock_file.assert_called_once_with(
+            os.path.expanduser("~/.rally/globals"),
+            ["RALLY_TASK=%s\n" % task_id])
+
+    @mock.patch("rally.cmd.commands.task.db.task_get")
+    def test_use_not_found(self, mock_task):
+        task_id = "ddc3f8ba-082a-496d-b18f-72cdf5c10a14"
+        mock_task.side_effect = exceptions.TaskNotFound(uuid=task_id)
+        self.assertRaises(exceptions.TaskNotFound, self.task.use, task_id)
