@@ -17,6 +17,7 @@ import os
 
 import mock
 from oslo_config import cfg
+import requests
 
 from rally.verification.tempest import config
 from tests.unit import fakes
@@ -297,14 +298,21 @@ class ConfigTestCase(test.TestCase):
         self.assertEqual(self.conf_generator.conf.get(
             "service_available", "horizon"), "True")
 
-    @mock.patch('six.moves.builtins.open', side_effect=mock.mock_open(),
+    @mock.patch("rally.verification.tempest.config.requests.get")
+    def test__set_service_not_available_horizon(self, mock_requests_get):
+        mock_requests_get.side_effect = requests.Timeout()
+        self.conf_generator._set_service_available()
+        self.assertEqual(self.conf_generator.conf.get(
+            "service_available", "horizon"), "False")
+
+    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open(),
                 create=True)
     def test_write_config(self, mock_open):
         self.conf_generator.conf = mock.Mock()
-        file_name = '/path/to/fake/conf'
+        file_name = "/path/to/fake/conf"
 
         self.conf_generator.write_config(file_name)
 
-        mock_open.assert_called_once_with(file_name, 'w+')
+        mock_open.assert_called_once_with(file_name, "w+")
         self.conf_generator.conf.write.assert_called_once_with(
             mock_open.side_effect())
